@@ -1,5 +1,4 @@
 import os
-import tempfile
 
 # SERVER CONFIGURATION
 
@@ -24,8 +23,7 @@ AUTHENTICATION = "PAMAuthentication"
 PROCESS_SWITCHING = True
 
 # Flask cache configuration
-CACHE_TYPE = "filesystem"
-CACHE_DIR = os.path.join(tempfile.gettempdir(), "pegasus-service")
+CACHE_TYPE = "flask_caching.backends.SimpleCache"
 
 #
 # Authorization -
